[Libreoffice-commits] core.git: basic/source embeddedobj/test filter/source framework/inc odk/examples qadevOOo/tests unotools/source wizards/com xmlsecurity/source

Adolfo Jayme Barrientos fitojb at ubuntu.com
Tue Jul 21 02:54:55 PDT 2015


 basic/source/sbx/sbxcurr.cxx                                              |    4 +-
 embeddedobj/test/Container1/NativeView.java                               |   16 +++++-----
 filter/source/config/cache/typedetection.cxx                              |    6 +--
 framework/inc/helper/ocomponentenumeration.hxx                            |    2 -
 framework/inc/helper/persistentwindowstate.hxx                            |    2 -
 framework/inc/interaction/quietinteraction.hxx                            |    4 +-
 odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java |    8 ++---
 qadevOOo/tests/java/ifc/drawing/_XShape.java                              |    2 -
 qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java            |    4 +-
 unotools/source/config/configitem.cxx                                     |    2 -
 wizards/com/sun/star/wizards/agenda/AgendaDocument.py                     |    2 -
 wizards/com/sun/star/wizards/agenda/TopicsControl.py                      |   10 +++---
 xmlsecurity/source/framework/saxeventkeeperimpl.cxx                       |    2 -
 13 files changed, 32 insertions(+), 32 deletions(-)

New commits:
commit 3e926736c7a1ec0a622ff446466113d9ccd8cb11
Author: Adolfo Jayme Barrientos <fitojb at ubuntu.com>
Date:   Tue Jul 21 04:52:14 2015 -0500

    Miscellaneous typos
    
    Change-Id: I5187364d420ab78c36a91632efab9c32951d867a

diff --git a/basic/source/sbx/sbxcurr.cxx b/basic/source/sbx/sbxcurr.cxx
index 0c9b8d3..56defb0 100644
--- a/basic/source/sbx/sbxcurr.cxx
+++ b/basic/source/sbx/sbxcurr.cxx
@@ -158,7 +158,7 @@ static sal_Int64 ImpStringToCurrency( const OUString &rStr )
     OUString sTmp( rStr.trim() );
     const sal_Unicode* p =  sTmp.getStr();
 
-    // normalise string number by removeing thousands & decimal point separators
+    // normalise string number by removing thousand & decimal point separators
     OUStringBuffer sNormalisedNumString( sTmp.getLength() +  nFractDigit );
 
     if ( *p == '-'  || *p == '+' )
@@ -195,7 +195,7 @@ static sal_Int64 ImpStringToCurrency( const OUString &rStr )
 
     }
     // can we raise error here ? ( previous behaviour was more forgiving )
-    // so... not sure that could bread existing code, lets see if anyone
+    // so... not sure that could break existing code, let's see if anyone
     // complains.
 
     if ( p != sTmp.getStr() + sTmp.getLength() )
diff --git a/embeddedobj/test/Container1/NativeView.java b/embeddedobj/test/Container1/NativeView.java
index d53cc15..e757ed3 100644
--- a/embeddedobj/test/Container1/NativeView.java
+++ b/embeddedobj/test/Container1/NativeView.java
@@ -61,10 +61,10 @@ public class NativeView extends java.awt.Canvas
      * ( e.g. get the window handle and necessary system information )
      *
      * Why here?
-     * Because the handle seems to be available for already visible windows
-     * only. So it's the best place to get it. Special helper method
-     * can be called more than ones - but call native code one times only
-     * and safe the handle and the system type on our members maHandle/maSystem!
+     * Because the handle seems to be available for already-visible windows
+     * only. So it's the best place to get it. The special helper method
+     * can be called more than once - but call native code one time only
+     * and save the handle and the system type on our members maHandle/maSystem!
      */
     public void setVisible( boolean bState )
     {
@@ -123,11 +123,11 @@ public class NativeView extends java.awt.Canvas
      * windows in a java UI container.
      *
      * Note:
-     * Native code for windows register special function pointer to handle
-     * window messages ... But if it doesn't check for an already registered
+     * Native code for Windows registers a special function pointer to handle
+     * window messages... But if it doesn't check for an already-registered
      * instance of this handler it will do it twice and produce a stack overflow
-     * because such method call herself in a never ending loop ...
-     * So we try to use the JNI code one times only and safe already getted
+     * because such method calls itself in a never-ending loop...
+     * So we try to use the JNI code one time only and save already-obtained
      * information inside this class.
      */
     public  native int  getNativeWindowSystemType();
diff --git a/filter/source/config/cache/typedetection.cxx b/filter/source/config/cache/typedetection.cxx
index bb7d22a..ffeab2a 100644
--- a/filter/source/config/cache/typedetection.cxx
+++ b/filter/source/config/cache/typedetection.cxx
@@ -763,8 +763,8 @@ bool TypeDetection::impl_getPreselectionForDocumentService(
     // step over all filters, and check if its registered type
     // match the given URL.
     // But use temp. list of "preselected types" instead of incoming rFlatTypes list!
-    // The reason behind: we must filter the getted results. And copying of stl entries
-    // is an easier job then removing it .-)
+    // The reason behind: we must filter the obtained results. And copying stl entries
+    // is an easier job than removing them .-)
     for (OUStringList::const_iterator pFilter  = lFilters.begin();
          pFilter != lFilters.end();
          ++pFilter)
@@ -895,7 +895,7 @@ OUString TypeDetection::impl_detectTypeFlatAndDeep(      utl::MediaDescriptor& r
     // d) detect service return a valid result    => return its decision
     // e) detect service return an invalid result
     //    or any needed information could not be
-    //    getted from the cache                   => ignore it, and continue with search
+    //    obtained from the cache                 => ignore it, and continue with search
 
     for (FlatDetection::const_iterator pFlatIt  = lFlatTypes.begin();
                                        pFlatIt != lFlatTypes.end()  ;
diff --git a/framework/inc/helper/ocomponentenumeration.hxx b/framework/inc/helper/ocomponentenumeration.hxx
index 33d8951..e1e5078 100644
--- a/framework/inc/helper/ocomponentenumeration.hxx
+++ b/framework/inc/helper/ocomponentenumeration.hxx
@@ -88,7 +88,7 @@ class OComponentEnumeration :   public ::cppu::WeakImplHelper2< ::com::sun::star
         /*-****************************************************************************************************
             @short      check count of accessible elements of enumeration
             @descr      You can call this method to get information about accessible elements in future.
-                        Elements you have already getted are not accessible!
+                        Elements you have already gotten are not accessible!
 
             @seealso    interface XEnumeration
             @return     sal_True  = if more elements accessible<BR>
diff --git a/framework/inc/helper/persistentwindowstate.hxx b/framework/inc/helper/persistentwindowstate.hxx
index e669127..13dc1e1 100644
--- a/framework/inc/helper/persistentwindowstate.hxx
+++ b/framework/inc/helper/persistentwindowstate.hxx
@@ -117,7 +117,7 @@ class PersistentWindowState :   public  ::cppu::WeakImplHelper2<
 
             @param  sModuleName
                     identifies the application module, where the
-                    information should be getted for.
+                    information should be obtained for.
 
             @return [string]
                     contains the information about position and size.
diff --git a/framework/inc/interaction/quietinteraction.hxx b/framework/inc/interaction/quietinteraction.hxx
index 8af1bc9..5f084fd 100644
--- a/framework/inc/interaction/quietinteraction.hxx
+++ b/framework/inc/interaction/quietinteraction.hxx
@@ -84,8 +84,8 @@ class QuietInteraction : public  ::cppu::WeakImplHelper1<
 
         /**
             @short      return the handled interaction request
-            @descr      We saved any getted interaction request internally.
-                        May the outside user of this class is interessted
+            @descr      We saved any obtained interaction request internally.
+                        Maybe the outside user of this class is interested
                         on that. Especially we got an unknown interaction
                         and aborted it hard.
 
diff --git a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java
index efd057f..30892dd 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java
+++ b/odk/examples/DevelopersGuide/OfficeDev/DesktopEnvironment/NativeView.java
@@ -141,11 +141,11 @@ public class NativeView extends java.awt.Canvas
      * windows in a java UI container.
      *
      * Note:
-     * Native code for windows register special function pointer to handle
-     * window messages ... But if it doesn't check for an already registered
+     * Native code for Windows registers a special function pointer to handle
+     * window messages... But if it doesn't check for an already-registered
      * instance of this handler it will do it twice and produce a stack overflow
-     * because such method call herself in a never ending loop ...
-     * So we try to use the JNI code one time only and save already getted
+     * because such method calls itself in a never-ending loop...
+     * So we try to use the JNI code one time only and save already-obtained
      * information inside this class.
      */
     public  native int  getNativeWindowSystemType();
diff --git a/qadevOOo/tests/java/ifc/drawing/_XShape.java b/qadevOOo/tests/java/ifc/drawing/_XShape.java
index 97e9b36..03b3132 100644
--- a/qadevOOo/tests/java/ifc/drawing/_XShape.java
+++ b/qadevOOo/tests/java/ifc/drawing/_XShape.java
@@ -136,7 +136,7 @@ public class _XShape extends MultiMethodTest {
         result &= (sNew.Height-gSize.Height <= 2) && (sNew.Width-gSize.Width <= 2);
 
         if (result && ((sNew.Height-gSize.Height != 0) || (sNew.Width-gSize.Width != 0))){
-            log.println("NOTE: there is a difference between the expected and the getted value. " +
+            log.println("NOTE: there is a difference between the expected and the gotten value. " +
                     "This might be ok because of problems in calculation from points <-> twips");
         }
         tRes.tested("setSize()", result);
diff --git a/qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java b/qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java
index 14fa235..e0f3ff9 100644
--- a/qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java
+++ b/qadevOOo/tests/java/ifc/inspection/_XObjectInspectorModel.java
@@ -105,7 +105,7 @@ public class _XObjectInspectorModel extends MultiMethodTest {
         boolean result = (minHelpTextLines.intValue() == getMinHelpTextLines);
 
         if (!result)
-            log.println("FAILED: value:" + minHelpTextLines + " getted value:" + getMinHelpTextLines);
+            log.println("FAILED: value:" + minHelpTextLines + " gotten value:" + getMinHelpTextLines);
 
         tRes.tested("MinHelpTextLines()", result) ;
     }
@@ -123,7 +123,7 @@ public class _XObjectInspectorModel extends MultiMethodTest {
         boolean result = (maxHelpTextLines.intValue() == getMaxHelpTextLines);
 
         if (!result)
-            log.println("FAILED: expected value:" + maxHelpTextLines + " getted value:" + getMaxHelpTextLines);
+            log.println("FAILED: expected value:" + maxHelpTextLines + " gotten value:" + getMaxHelpTextLines);
 
         tRes.tested("MaxHelpTextLines()", result);
     }
diff --git a/unotools/source/config/configitem.cxx b/unotools/source/config/configitem.cxx
index e05d960..bb46aa7 100644
--- a/unotools/source/config/configitem.cxx
+++ b/unotools/source/config/configitem.cxx
@@ -279,7 +279,7 @@ void ConfigItem::impl_unpackLocalizedProperties(    const   Sequence< OUString >
     sal_Int32                   nPropertyCounter;    // counter of inner loop for Sequence< PropertyValue >
     sal_Int32                   nPropertiesSize;     // marks end of inner loop
     OUString                    sNodeName;           // base name of node ( e.g. "UIName/" ) ... expand to locale ( e.g. "UIName/de" )
-    Sequence< PropertyValue >   lProperties;         // localized values of an configuration entry getted from lInValues-Any
+    Sequence< PropertyValue >   lProperties;         // localized values of an configuration entry gotten from lInValues-Any
 
     // Optimise follow algorithm ... A LITTLE BIT :-)
     // There exist two different possibilities:
diff --git a/wizards/com/sun/star/wizards/agenda/AgendaDocument.py b/wizards/com/sun/star/wizards/agenda/AgendaDocument.py
index b72eede..06cb6a3 100644
--- a/wizards/com/sun/star/wizards/agenda/AgendaDocument.py
+++ b/wizards/com/sun/star/wizards/agenda/AgendaDocument.py
@@ -724,7 +724,7 @@ class Topics(object):
     We hold the format of the last row, because one might wish to give it
     a special format, other than the one on the bottom of each topic.
     The left and right borders of the whole table are, on the other side,
-    part of the topics rows format, and need not be preserved separateley.
+    part of the topics rows format, and need not be preserved separately.
     '''
     table = None
     lastRowFormat = []
diff --git a/xmlsecurity/source/framework/saxeventkeeperimpl.cxx b/xmlsecurity/source/framework/saxeventkeeperimpl.cxx
index 6bbd167..4eea017 100644
--- a/xmlsecurity/source/framework/saxeventkeeperimpl.cxx
+++ b/xmlsecurity/source/framework/saxeventkeeperimpl.cxx
@@ -462,7 +462,7 @@ void SAXEventKeeperImpl::smashBufferNode(
  *  empty
  *
  *   NOTES
- *  when removeing a Blocker's BufferNode, the bClearRoot flag should be
+ *  when removing a Blocker's BufferNode, the bClearRoot flag should be
  *  true. Because a Blocker can buffer many SAX events which are not used
  *  by any other ElementCollector or Blocker.
  *  When the bClearRoot is set to true, the root BufferNode will be first


More information about the Libreoffice-commits mailing list
diff --git a/wizards/com/sun/star/wizards/agenda/TopicsControl.py b/wizards/com/sun/star/wizards/agenda/TopicsControl.py
index 14f18e8..5c83ba3 100644
--- a/wizards/com/sun/star/wizards/agenda/TopicsControl.py
+++ b/wizards/com/sun/star/wizards/agenda/TopicsControl.py
@@ -193,11 +193,11 @@ class TopicsControl(ControlScroller):
         self.focusGained2(xc)
 
     '''
     Sometimes I set the focus programatically to a control
     (for example when moving a row up or down, the focus should move
     with it).
     In such cases, no VCL event is being triggered so it must
-    be called programtically.
+    be called programmatically.
     This is done by this method.
     @param control
     '''
@@ -608,7 +608,7 @@ class TopicsControl(ControlScroller):
     After moving row X to X+/-1, the selection (or cursor position) of the
     last focused control should be restored.
     The control's row is the given guiRow.
-    The control's column is detecte4d according to the given event.
+    The control's column is detected according to the given event.
     This method is called as subsequent to different events,
     thus it is comfortable to use the event here to detect the column,
     rather than in the different event methods.
@@ -693,7 +693,7 @@ class TopicsControl(ControlScroller):
     '''
     updates a single cell in the preview document.
     Is called when a single value is changed, since we really
-    don't have to update the whole row for one small changhe...
+    don't have to update the whole row for one small change...
     @param row the data row to update (topic number).
     @param column the column to update (a gui column, not a document column).
     @param data the data of the entire row.
@@ -707,7 +707,7 @@ class TopicsControl(ControlScroller):
             traceback.print_exc()
 
     '''
-    when removeing rows, this method updates
+    when removing rows, this method updates
     the preview document to show the number of rows
     according to the data model.
     '''
@@ -193,11 +193,11 @@ class TopicsControl(ControlScroller):
 
     '''
-    Sometimes I set the focus programatically to a control
+    Sometimes I set the focus programmatically to a control
     (for example when moving a row up or down, the focus should move
     with it).